@@ -9,8 +9,11 @@ trap "popd" EXIT
 
 # Remove any build or runtime arifacts
 # ... python can be a bit noisy with artifacts floating around the project dir
-rm -rfv build dist result \
-	src/beancount_docverif.egg-info "test/test_log"
+rm -rfv \
+	.eggs .tox \
+	build dist result \
+	"test/test_log"
+	beancount_docverif.egg-info \
 find . \( -name "__pycache__" -o -name "*.pyc" \) -exec rm -rfv '{}' \; \
 	2>/dev/null || true
 
